==> release.12.1.61.1.tgz: cgi-cpn/utils/prontus_convert_plts.pl <==
#!/usr/bin/perl
use utf8;
use strict;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);
    $pathLibsProntus =~ s/\/[^\/]+\/?$//;
    unshift(@INC,$pathLibsProntus);
}

use File::Copy;
use prontus_varglb; &prontus_varglb::init();
use lib_prontus;
use glib_fildir_03;

my $mode_test = 0;
my $counter = 0;
my $rule = '-' x 80;

my %resumen;
my $EXT_FILTER = 'html';

main:{
    lib_prontus::setUtf8();

    my $dir;

    if (defined($ARGV[0])) {
        $dir = $ARGV[0];
        $dir =~ s/\/$//g;
    }
    if ($dir eq '') {
        print "Modo de uso:\n";
        print "perl prontus_convert_plts.pl prontus\n";
        print "perl prontus_convert_plts.pl /path/a/directorio\n";
        print "Se puede agregar en el ultimo parametro una extesión específica a procesar, por ej 'json'\n";
        print "perl prontus_convert_plts.pl prontus json\n";
        print "perl prontus_convert_plts.pl /path/a/directorio json\n";
        print "Si se agrega 'all' al final del comando se procesan todos los archivos encontrados,\n";
        print "en caso contrario solo los archivos de extension .html\n";
        print "perl prontus_convert_plts.pl prontus all\n";
        print "perl prontus_convert_plts.pl /path/a/directorio all\n";
        exit
    }
    if (defined($ARGV[1])) {
        $EXT_FILTER = lc($ARGV[1]);
    }

    print $rule. "\n";
    if ($dir ne 'prontus')  {
        if (!-d $dir)  {
            print "[$dir] DIR no es directorio\n";
            exit;
        }
        if (!-d "$dir.bkp") {
            $dir =~ /(.+)\/([^\/]+)$/;
            my $base = $1;
            my $folder = $2;
            &glib_fildir_03::copy_tree($base, $folder,$base, "$folder.bkp");
        }
        print "$dir\n";
        &procesa_dir($dir);
    } else {
        my $input;
        my @prontus_dirs = &lib_prontus::get_prontus_dirs();
        my $prontus_count = scalar @prontus_dirs;
        # Iterar por cada prontus
        foreach my $prontus_id (@prontus_dirs) {
            $input = "$prontus_varglb::DIR_SERVER/$prontus_id/cpan/fid" ;
            if (!-d "$prontus_varglb::DIR_SERVER/$prontus_id/cpan/fid.bkp") {
                &glib_fildir_03::copy_tree("$prontus_varglb::DIR_SERVER/$prontus_id/cpan", 'fid',"$prontus_varglb::DIR_SERVER/$prontus_id/cpan", 'fid.bkp') if (!$mode_test);
            }
            &procesa_dir($input);

            $input = "$prontus_varglb::DIR_SERVER/$prontus_id/plantillas" ;
            if (!-d "$prontus_varglb::DIR_SERVER/$prontus_id/plantillas.bkp") {
                &glib_fildir_03::copy_tree("$prontus_varglb::DIR_SERVER/$prontus_id", 'plantillas',"$prontus_varglb::DIR_SERVER/$prontus_id", 'plantillas.bkp') if (!$mode_test);
            }
            &procesa_dir($input);
            # procesa configuracion de xcoding si encuentra
            $input = "$prontus_varglb::DIR_SERVER/$prontus_id$prontus_varglb::XCODING_DATA_PATH$prontus_varglb::XCODE_CFG";
            if (-s $input) {
                if (! -f "$input.bak") {
                    &File::Copy::copy($input, "$input.bak") if (!$mode_test);
                }
                print $input ."\n";
                my $file = glib_fildir_03::read_file($input);
                my $aux = $file;
                while($file =~ /(MULTIMEDIA\w+\.\w+)\.\w+\s*=\s*'.+?'/sig) {
                    my $config = $1;
                    my $config_lower = lc $config;
                    $aux =~ s/\Q$config\E/$config_lower/sg;
                }
                while($file =~ /(MULTIMEDIA\w+)\.\w+\s*=\s*'(.+?)'/ig) {
                    my $config = $1;
                    my $config_lower = lc $config;
                    $aux =~ s/\Q$config\E/$config_lower/sg;
                }
                glib_fildir_03::write_file($input, $aux) if (!$mode_test);
            }
        }
    }

    print 'Se encontraron ' . $counter .  " marcas:\n";
    #~ use Data::Dumper;
    #~ print Dumper(\%resumen);
    foreach my $tipo_ext (keys %resumen){
        print "$tipo_ext :" . scalar @{$resumen{$tipo_ext}} .  " archivos\n";
    }
};

#-----------------------------------------------------------------------#
sub procesa_dir {
    my $input = $_[0];

    unless(-d $input) {
        die "El directorio $input no existe.";
    }
    $input = $input . '/' unless ($input =~ /\/$/);

    my @entries = glib_fildir_03::lee_dir($input);
    foreach my $k (@entries) {
        next if($k eq '.' || $k eq '..');
        if (-f $input . $k) {
            &procesa_file($k, $input);
        } elsif(-d $input . $k) {
            &procesa_dir($input . $k);
        }
    }
};

#-----------------------------------------------------------------------#
sub procesa_file {
    my($filename, $path) = ($_[0], $_[1]);
    my $filepath = $path . $filename;
    if ($EXT_FILTER ne 'all'  && $filename =~ /\.(.+)$/) {
        if ($EXT_FILTER ne lc($1)) {
            return;
        }
    }

    if (-f $filepath) {
        my $file = glib_fildir_03::read_file($filepath);
        print "File [$path$filename]:\n";
        my $aux = $file;
        # procesar PF
        while ($file =~ /(%%(_pf_\w+)\((['"].+?['"])\)%%)/ig) {
            $counter++;
            my $marca = $1;
            my $operacion = $2;
            my $args = $3;
            $args = &parse_prontus($args, $filename);
            # el nombre de la funcion debe mantener el case, solo pf debe ser en minúsculas
            $operacion =~ s/_PF/_pf/i;
            my $marca_lower = '%%' . $operacion . '('. $args .')%%';
            $aux =~ s/\Q$marca\E/$marca_lower/sg;
            print "\t*0 PF reemplazada [$marca] -> [$marca_lower]\n";
        }

        # procesar el resto de las marcas
        $file = &parse_prontus($aux);

        $aux = $file;
        while ($file =~ /"(RDO_[^"]+)"/ig) {
            my $marca = $1;
            my $lower = lc($1);
            $aux =~ s/$marca/$lower/ig;
            print "\t*0 PF reemplazada [$marca] -> [$lower]\n";
        }
        while($file =~ /"(CMB_[^"]+)"/ig) {
            my $marca = $1;
            my $lower = lc($1);
            $aux =~ s/$marca/$lower/ig;
            print "\t*0 PF reemplazada [$marca] -> [$lower]\n";
        }
        while($file =~ /"(CHK_[^"]+)"/ig) {
            my $marca = $1;
            my $lower = lc($1);
            $aux =~ s/$marca/$lower/ig;
            print "\t*0 PF reemplazada [$marca] -> [$lower]\n";
        }

        $file = $aux;

        $filename =~ /((\.[^.\s]+)+)$/;
        my $ext = $1;
        push @{$resumen{$ext}}, $filename;

        glib_fildir_03::write_file($filepath, $file) if (!$mode_test);
    }
}

sub parse_prontus {
    my $file = $_[0];
    my $aux = $file;

    while ($file =~ /(%%[^%]+%%)/g) {
        $counter++;
        my $marca = $1;
        # la salta porque ya se procesó
        if ($marca =~ /%%_pf_/) {
            next;
        }

        # Es una marca con parametros %%if(var = valor)%% o similar
        if ($marca =~ /%%(\w+)\(([^\(\)]+?)\)%%/) {
            my $operacion = $1;
            my $args = $2;
            # es una marca de tipo if, primer parametro es nombre de variable, segundo valor a comparar
            if ($operacion =~ /if/i) {
                # variable unica como parametro, por ej %%IF(fotofija_port_80x80)%%
                if ($args =~ /^\s*([^=!<>\s]+)\s*$/) {
                    my $marca_lower = '%%' . lc($operacion) . '('. lc($1) .')%%';
                    $aux =~ s/\Q$marca\E/$marca_lower/sg;
                    print "\t*1 marca reemplazada [$marca] -> [$marca_lower]\n";
                }
                # comparacion de variable, por ej %%IF(_fid eq fid_noticia)%%
                elsif ($args =~ /([^=!<>\s]+)\s*(={1,2}|\!=|>|<|>=|<=|eq|ne|lt|gt|le|ge|~|!~)\s*([^=!<>]+)/) {
                    my $id_var = $1;
                    my $comparador = $2;
                    my $valor = $3;

                    my $marca_lower = '%%' . lc($operacion) . '('. lc($id_var)." $comparador $valor)%%";
                    $aux =~ s/\Q$marca\E/$marca_lower/sg;
                    print "\t*2 marca reemplazada [$marca] -> [$marca_lower]\n";
                }
            } else {
                my $marca_lower =  "%%". lc($operacion) ."($args)%%";
                $aux =~ s/\Q$marca\E/$marca_lower/sg;
                print "\t*3 marca reemplazada [$marca] -> [$marca_lower]\n";
            }
            # para marcas tipo %%fotofija_port1000x500(1000,500, Foto (1000 x 500px))%%
            # o %%loop8("Destacados, Importantes () ",fid_general|fid_link)%%
        } elsif ($marca =~ /%%(\w+)\((.+?)\)%%/) {
            my $operacion = $1;
            my $args = $2;
            my $marca_lower =  "%%". lc($operacion) ."($args)%%";
            $aux =~ s/\Q$marca\E/$marca_lower/sg;
            print "\t*4 marca reemplazada [$marca] -> [$marca_lower]\n";
        } else {
            my $marca_lower = lc $marca;
            $aux =~ s/\Q$marca\E/$marca_lower/sg;

            $marca =~ /%%([^%]+)%%/;
            my $name = lc($1);
            $aux =~ s/name=["']\Q$name\E["']/name=\"$name\"/isg;
            print "\t*5 marca reemplazada [$marca] -> [$marca_lower] [$name]\n";
        }
    }
    return $aux;
}

==> release.12.2.28.1.tgz: cgi-cpn/utils/prontus_convert_plts.pl <==
#!/usr/bin/perl
use utf8;
use strict;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);
    $pathLibsProntus =~ s/\/[^\/]+\/?$//;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use prontus_varglb;
prontus_varglb::init();

use File::Copy;
use glib_fildir_03;
use lib_prontus;
use lib_utils;
##/libs##

my $mode_test = 0;
my $counter = 0;
my $rule = '-' x 80;

my %resumen;
my $EXT_FILTER = 'html';

main:{
    lib_utils::setUtf8();

    my $dir;

    if (defined($ARGV[0])) {
        $dir = $ARGV[0];
        $dir =~ s/\/$//g;
    }
    if ($dir eq '') {
        print "Modo de uso:\n";
        print "perl prontus_convert_plts.pl prontus\n";
        print "perl prontus_convert_plts.pl /path/a/directorio\n";
        print "Se puede agregar en el ultimo parametro una extesión específica a procesar, por ej 'json'\n";
        print "perl prontus_convert_plts.pl prontus json\n";
        print "perl prontus_convert_plts.pl /path/a/directorio json\n";
        print "Si se agrega 'all' al final del comando se procesan todos los archivos encontrados,\n";
        print "en caso contrario solo los archivos de extension .html\n";
        print "perl prontus_convert_plts.pl prontus all\n";
        print "perl prontus_convert_plts.pl /path/a/directorio all\n";
        exit
    }
    if (defined($ARGV[1])) {
        $EXT_FILTER = lc($ARGV[1]);
    }

    print $rule. "\n";
    if ($dir ne 'prontus')  {
        if (!-d $dir)  {
            print "[$dir] DIR no es directorio\n";
            exit;
        }
        if (!-d "$dir.bkp") {
            $dir =~ /(.+)\/([^\/]+)$/;
            my $base = $1;
            my $folder = $2;
            glib_fildir_03::copy_tree($base, $folder,$base, "$folder.bkp");
        }
        print "$dir\n";
        &procesa_dir($dir);
    } else {
        my $input;
        my @prontus_dirs = lib_prontus::get_prontus_dirs();
        my $prontus_count = scalar @prontus_dirs;
        # Iterar por cada prontus
        foreach my $prontus_id (@prontus_dirs) {
            $input = "$prontus_varglb::DIR_SERVER/$prontus_id/cpan/fid" ;
            if (!-d "$prontus_varglb::DIR_SERVER/$prontus_id/cpan/fid.bkp") {
                glib_fildir_03::copy_tree("$prontus_varglb::DIR_SERVER/$prontus_id/cpan", 'fid',"$prontus_varglb::DIR_SERVER/$prontus_id/cpan", 'fid.bkp') if (!$mode_test);
            }
            &procesa_dir($input);

            $input = "$prontus_varglb::DIR_SERVER/$prontus_id/plantillas" ;
            if (!-d "$prontus_varglb::DIR_SERVER/$prontus_id/plantillas.bkp") {
                glib_fildir_03::copy_tree("$prontus_varglb::DIR_SERVER/$prontus_id", 'plantillas',"$prontus_varglb::DIR_SERVER/$prontus_id", 'plantillas.bkp') if (!$mode_test);
            }
            &procesa_dir($input);
            # procesa configuracion de xcoding si encuentra
            $input = "$prontus_varglb::DIR_SERVER/$prontus_id$prontus_varglb::XCODING_DATA_PATH$prontus_varglb::XCODE_CFG";
            if (-s $input) {
                if (! -f "$input.bak") {
                    File::Copy::copy($input, "$input.bak") if (!$mode_test);
                }
                print $input ."\n";
                my $file = glib_fildir_03::read_file($input);
                my $aux = $file;
                while($file =~ /(MULTIMEDIA\w+\.\w+)\.\w+\s*=\s*'.+?'/sig) {
                    my $config = $1;
                    my $config_lower = lc $config;
                    $aux =~ s/\Q$config\E/$config_lower/sg;
                }
                while($file =~ /(MULTIMEDIA\w+)\.\w+\s*=\s*'(.+?)'/ig) {
                    my $config = $1;
                    my $config_lower = lc $config;
                    $aux =~ s/\Q$config\E/$config_lower/sg;
                }
                glib_fildir_03::write_file($input, $aux) if (!$mode_test);
            }
        }
    }

    print 'Se encontraron ' . $counter .  " marcas:\n";
    #~ use Data::Dumper;
    #~ print Dumper(\%resumen);
    foreach my $tipo_ext (keys %resumen){
        print "$tipo_ext :" . scalar @{$resumen{$tipo_ext}} .  " archivos\n";
    }
};

#-----------------------------------------------------------------------#
sub procesa_dir {
    my $input = $_[0];

    unless(-d $input) {
        die "El directorio $input no existe.";
    }
    $input = $input . '/' unless ($input =~ /\/$/);

    my @entries = glib_fildir_03::lee_dir($input);
    foreach my $k (@entries) {
        next if($k eq '.' || $k eq '..');
        if (-f $input . $k) {
            &procesa_file($k, $input);
        } elsif(-d $input . $k) {
            &procesa_dir($input . $k);
        }
    }
};

#-----------------------------------------------------------------------#
sub procesa_file {
    my($filename, $path) = ($_[0], $_[1]);
    my $filepath = $path . $filename;
    if ($EXT_FILTER ne 'all'  && $filename =~ /\.(.+)$/) {
        if ($EXT_FILTER ne lc($1)) {
            return;
        }
    }

    if (-f $filepath) {
        my $file = glib_fildir_03::read_file($filepath);
        print "File [$path$filename]:\n";
        my $aux = $file;
        # procesar PF
        while ($file =~ /(%%(_pf_\w+)\((['"].+?['"])\)%%)/ig) {
            $counter++;
            my $marca = $1;
            my $operacion = $2;
            my $args = $3;
            $args = &parse_prontus($args, $filename);
            # el nombre de la funcion debe mantener el case, solo pf debe ser en minúsculas
            $operacion =~ s/_PF/_pf/i;
            my $marca_lower = '%%' . $operacion . '('. $args .')%%';
            $aux =~ s/\Q$marca\E/$marca_lower/sg;
            print "\t*0 PF reemplazada [$marca] -> [$marca_lower]\n";
        }

        # procesar el resto de las marcas
        $file = &parse_prontus($aux);

        $aux = $file;
        while ($file =~ /"(RDO_[^"]+)"/ig) {
            my $marca = $1;
            my $lower = lc($1);
            $aux =~ s/$marca/$lower/ig;
            print "\t*0 PF reemplazada [$marca] -> [$lower]\n";
        }
        while($file =~ /"(CMB_[^"]+)"/ig) {
            my $marca = $1;
            my $lower = lc($1);
            $aux =~ s/$marca/$lower/ig;
            print "\t*0 PF reemplazada [$marca] -> [$lower]\n";
        }
        while($file =~ /"(CHK_[^"]+)"/ig) {
            my $marca = $1;
            my $lower = lc($1);
            $aux =~ s/$marca/$lower/ig;
            print "\t*0 PF reemplazada [$marca] -> [$lower]\n";
        }

        $file = $aux;

        $filename =~ /((\.[^.\s]+)+)$/;
        my $ext = $1;
        push @{$resumen{$ext}}, $filename;

        glib_fildir_03::write_file($filepath, $file) if (!$mode_test);
    }
}

sub parse_prontus {
    my $file = $_[0];
    my $aux = $file;

    while ($file =~ /(%%[^%]+%%)/g) {
        $counter++;
        my $marca = $1;
        # la salta porque ya se procesó
        if ($marca =~ /%%_pf_/) {
            next;
        }

        # Es una marca con parametros %%if(var = valor)%% o similar
        if ($marca =~ /%%(\w+)\(([^\(\)]+?)\)%%/) {
            my $operacion = $1;
            my $args = $2;
            # es una marca de tipo if, primer parametro es nombre de variable, segundo valor a comparar
            if ($operacion =~ /if/i) {
                # variable unica como parametro, por ej %%IF(fotofija_port_80x80)%%
                if ($args =~ /^\s*([^=!<>\s]+)\s*$/) {
                    my $marca_lower = '%%' . lc($operacion) . '('. lc($1) .')%%';
                    $aux =~ s/\Q$marca\E/$marca_lower/sg;
                    print "\t*1 marca reemplazada [$marca] -> [$marca_lower]\n";
                }
                # comparacion de variable, por ej %%IF(_fid eq fid_noticia)%%
                elsif ($args =~ /([^=!<>\s]+)\s*(={1,2}|\!=|>|<|>=|<=|eq|ne|lt|gt|le|ge|~|!~)\s*([^=!<>]+)/) {
                    my $id_var = $1;
                    my $comparador = $2;
                    my $valor = $3;

                    my $marca_lower = '%%' . lc($operacion) . '('. lc($id_var)." $comparador $valor)%%";
                    $aux =~ s/\Q$marca\E/$marca_lower/sg;
                    print "\t*2 marca reemplazada [$marca] -> [$marca_lower]\n";
                }
            } else {
                my $marca_lower =  "%%". lc($operacion) ."($args)%%";
                $aux =~ s/\Q$marca\E/$marca_lower/sg;
                print "\t*3 marca reemplazada [$marca] -> [$marca_lower]\n";
            }
            # para marcas tipo %%fotofija_port1000x500(1000,500, Foto (1000 x 500px))%%
            # o %%loop8("Destacados, Importantes () ",fid_general|fid_link)%%
        } elsif ($marca =~ /%%(\w+)\((.+?)\)%%/) {
            my $operacion = $1;
            my $args = $2;
            my $marca_lower =  "%%". lc($operacion) ."($args)%%";
            $aux =~ s/\Q$marca\E/$marca_lower/sg;
            print "\t*4 marca reemplazada [$marca] -> [$marca_lower]\n";
        } else {
            my $marca_lower = lc $marca;
            $aux =~ s/\Q$marca\E/$marca_lower/sg;

            $marca =~ /%%([^%]+)%%/;
            my $name = lc($1);
            $aux =~ s/name=["']\Q$name\E["']/name=\"$name\"/isg;
            print "\t*5 marca reemplazada [$marca] -> [$marca_lower] [$name]\n";
        }
    }
    return $aux;
}
